package com.zbsz.aop;

import com.alibaba.fastjson2.JSON;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.*;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;

@Aspect
@Component
@Slf4j
public class LogAop {
    @Pointcut("execution( * com.zbsz.controller..*.*(..))")
    public void log() {}

    @Around("log()")
    public Object doAround(ProceedingJoinPoint joinPoint) throws Throwable {
        long startTime=System.currentTimeMillis();
        Object result=joinPoint.proceed();
        log.info("Response："+ JSON.toJSON(result));
        log.info("耗时："+(System.currentTimeMillis()-startTime));
        log.info("==================End=================");
        return result;
    }

    @Before("log()")
    public void doBefore(JoinPoint joinPoint) {
        ServletRequestAttributes attributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        HttpServletRequest request = attributes.getRequest();
        log.info("");
        log.info("==================Start=================");
        log.info("URL：" + request.getRequestURL().toString());
        log.info("Method：" + request.getMethod().toString());
        log.info("Class Method：" + joinPoint.getSignature().getDeclaringTypeName() + "," + joinPoint.getSignature().getName());
        log.info("客户端IP：" + request.getRemoteAddr());
        log.info("请求参数：" + JSON.toJSON(joinPoint.getArgs()));
    }

}
