package com.zbsz.config;

import com.zbsz.filter.TokenInterceptor;
import com.zbsz.service.UserService;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Import;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;
import springfox.bean.validators.configuration.BeanValidatorPluginsConfiguration;
import springfox.documentation.builders.ApiInfoBuilder;
import springfox.documentation.builders.PathSelectors;
import springfox.documentation.builders.RequestHandlerSelectors;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger2.annotations.EnableSwagger2WebMvc;

import javax.annotation.Resource;


/**
 * http://localhost:8601/doc.html
 */
@Configuration
@Import(BeanValidatorPluginsConfiguration.class)
@EnableSwagger2WebMvc
public class Swagger2Config implements WebMvcConfigurer {
    @Resource
    private UserService userService;

    @Bean
    public Docket createRestApi() {
        return new Docket(DocumentationType.SWAGGER_2)
                .apiInfo(new ApiInfoBuilder()
                        .title("指标设置 API")
                        .description("指标设置 API 说明")
                        .version("V-1.0")
                        .build())
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.zbsz.controller"))
                .paths(PathSelectors.any())
                .build();
    }

    //过滤器
    @Override
    public void addInterceptors(InterceptorRegistry registry) {
        //添加拦截器
        registry.addInterceptor(new TokenInterceptor(userService))
                .addPathPatterns("/**")
                .excludePathPatterns("/doc.html")
                .excludePathPatterns("/swagger-resources/**")
                .excludePathPatterns("/webjars/**")
                .excludePathPatterns("/v2/**")
                .excludePathPatterns("/favicon.ico")
                .excludePathPatterns("/swagger-ui.html/**")
                .excludePathPatterns("/keyPerson/callBackResult")
                .excludePathPatterns("/upload/**")
                .excludePathPatterns("/openapi/*");//白名单
    }

}
