package com.zbsz.controller;

import com.common.entity.Scene;
import com.common.entity.dic.IndicatorDic;
import com.common.entity.dic.AppDic;
import com.common.info.CodeMsg;
import com.zbsz.info.Result;
import com.zbsz.service.IndicatorDicService;
import com.zbsz.service.AppDicService;
import com.zbsz.service.SceneService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

@Slf4j
@RestController
@RequestMapping("/indicator")
@Api(tags = "服务接口")
public class IndicatorController {
    @Resource
    private SceneService sceneService;
    @Resource
    private IndicatorDicService indicatorDicService;
    @Resource
    private AppDicService appDicService;

    /**
     * 关联场景查询
     * @return Result
     */
    @ApiOperation(value = "获取关联场景",notes = "获取关联场景列表信息")
    @GetMapping("get_scenes")
    public Result getScenes(@RequestHeader(value = "userId",required = true)String token) {
        Result result = new Result();
        try {
            List<Scene> list = sceneService.list();
            result.setCode(CodeMsg.SUCCESS.getCode());
            result.setMsg(CodeMsg.SUCCESS.getMessage());
            result.setData(list);
            if(list!=null){
                result.setTotal((long) list.size());
            }else {
                result.setTotal(0L);
            }
            log.error("-------- 获取关联场景成功 ");
        }catch (Exception e){
            log.error("-------- 获取关联场景异常 : "+e.getMessage(),e);
            result.setCode(CodeMsg.FAILURE.getCode());
            result.setMsg(e.getMessage());
        }
        return result;
    }

    /**
     * 指标类型查询
     * @return Result
     */
    @ApiOperation(value = "获取指标类型",notes = "获取指标类型列表信息")
    @GetMapping("get_indicator_dic")
    public Result getIndicatorDic(@RequestHeader(value = "userId",required = true)String token) {
        Result result = new Result();
        try {
            List<IndicatorDic> list = indicatorDicService.list();
            result.setCode(CodeMsg.SUCCESS.getCode());
            result.setMsg(CodeMsg.SUCCESS.getMessage());
            result.setData(list);
            if(list!=null){
                result.setTotal((long) list.size());
            }else {
                result.setTotal(0L);
            }
            log.error("-------- 获取指标类型成功 ");
        }catch (Exception e){
            log.error("-------- 获取指标类型异常 : "+e.getMessage(),e);
            result.setCode(CodeMsg.FAILURE.getCode());
            result.setMsg(e.getMessage());
        }
        return result;
    }

    /**
     * 关联应用模块类型查询
     * @return Result
     */
    @ApiOperation(value = "获取关联应用模块类型",notes = "获取关联应用模块类型列表信息")
    @GetMapping("get_app_dic")
    public Result getModuleDic(@RequestHeader(value = "userId",required = true)String token) {
        Result result = new Result();
        try {
            List<AppDic> list = appDicService.list();
            result.setCode(CodeMsg.SUCCESS.getCode());
            result.setMsg(CodeMsg.SUCCESS.getMessage());
            result.setData(list);
            if(list!=null){
                result.setTotal((long) list.size());
            }else {
                result.setTotal(0L);
            }
            log.error("-------- 获取关联应用模块成功 ");
        }catch (Exception e){
            log.error("-------- 获取关联应用模块异常 : "+e.getMessage(),e);
            result.setCode(CodeMsg.FAILURE.getCode());
            result.setMsg(e.getMessage());
        }
        return result;
    }



}
